@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "akonadidatasourcequeries.h"
@@ -54,7 +36,7 @@ void DataSourceQueries::changeDefaultSource(Domain::DataSource::Ptr source)
 
 DataSourceQueries::DataSourceResult::Ptr DataSourceQueries::findTopLevel() const
 {
-    auto fetch = m_helpers->fetchCollections(Collection::root());
+    auto fetch = m_helpers->fetchCollections(Collection::root(), const_cast<DataSourceQueries*>(this));
     auto predicate = createFetchPredicate(Collection::root());
     m_integrator->bind("DataSourceQueries::findTopLevel", m_findTopLevel, fetch, predicate);
     return m_findTopLevel->result();
@@ -64,7 +46,7 @@ DataSourceQueries::DataSourceResult::Ptr DataSourceQueries::findChildren(Domain:
 {
     Collection root = m_serializer->createCollectionFromDataSource(source);
     auto &query = m_findChildren[root.id()];
-    auto fetch = m_helpers->fetchCollections(root);
+    auto fetch = m_helpers->fetchCollections(root, const_cast<DataSourceQueries*>(this));
     auto predicate = createFetchPredicate(root);
     m_integrator->bind("DataSourceQueries::findChildren", query, fetch, predicate);
     return query->result();
@@ -72,7 +54,7 @@ DataSourceQueries::DataSourceResult::Ptr DataSourceQueries::findChildren(Domain:
 
 DataSourceQueries::DataSourceResult::Ptr DataSourceQueries::findAllSelected() const
 {
-    auto fetch = m_helpers->fetchAllCollections();
+    auto fetch = m_helpers->fetchAllCollections(const_cast<DataSourceQueries*>(this));
     auto predicate = [this] (const Akonadi::Collection &collection) {
         return collection.isValid() && m_serializer->isSelectedCollection(collection);
     };
@@ -85,7 +67,7 @@ DataSourceQueries::ProjectResult::Ptr DataSourceQueries::findProjects(Domain::Da
 {
     Collection root = m_serializer->createCollectionFromDataSource(source);
     auto &query = m_findProjects[root.id()];
-    auto fetch = m_helpers->fetchItems(root);
+    auto fetch = m_helpers->fetchItems(root, const_cast<DataSourceQueries*>(this));
     auto predicate = [this, root] (const Akonadi::Item &item) {
         return root == item.parentCollection()
             && m_serializer->isProjectItem(item);
