@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "akonadistorage.h"
@@ -28,24 +10,37 @@
 
 #include <KCalCore/Todo>
 
-#include <AkonadiCore/CollectionCreateJob>
-#include <AkonadiCore/CollectionDeleteJob>
-#include <AkonadiCore/CollectionFetchScope>
-#include <AkonadiCore/CollectionModifyJob>
-#include <AkonadiCore/ItemCreateJob>
-#include <AkonadiCore/ItemDeleteJob>
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/ItemModifyJob>
-#include <AkonadiCore/ItemMoveJob>
-#include <AkonadiCore/TagFetchScope>
-#include <AkonadiCore/TransactionSequence>
+#include <AkonadiCore/Akonadi/CollectionCreateJob>
+#include <AkonadiCore/Akonadi/CollectionDeleteJob>
+#include <AkonadiCore/Akonadi/CollectionFetchScope>
+#include <AkonadiCore/Akonadi/CollectionModifyJob>
+#include <AkonadiCore/Akonadi/ItemCreateJob>
+#include <AkonadiCore/Akonadi/ItemDeleteJob>
+#include <AkonadiCore/Akonadi/ItemFetchJob>
+#include <AkonadiCore/Akonadi/ItemFetchScope>
+#include <AkonadiCore/Akonadi/ItemModifyJob>
+#include <AkonadiCore/Akonadi/ItemMoveJob>
+#include <AkonadiCore/Akonadi/TagFetchScope>
+#include <AkonadiCore/Akonadi/TransactionSequence>
 #include "akonadi/akonadicollectionfetchjobinterface.h"
 #include "akonadi/akonadiitemfetchjobinterface.h"
 #include "akonadi/akonadistoragesettings.h"
 
 using namespace Akonadi;
 
+namespace
+{
+    template<typename T>
+    QSet<T> listToSet(const QList<T> &list)
+    {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+        return list.toSet();
+#else
+        return {list.cbegin(), list.cend()};
+#endif
+    }
+}
+
 class CollectionJob : public CollectionFetchJob, public CollectionFetchJobInterface
 {
     Q_OBJECT
@@ -70,12 +65,12 @@ public:
 
         // Why the hell isn't fetchScope() const and returning a reference???
         auto self = const_cast<CollectionJob*>(this);
-        const auto allowedMimeTypes = self->fetchScope().contentMimeTypes().toSet();
+        const auto allowedMimeTypes = listToSet(self->fetchScope().contentMimeTypes());
 
         if (!allowedMimeTypes.isEmpty()) {
             collections.erase(std::remove_if(collections.begin(), collections.end(),
                                              [allowedMimeTypes] (const Collection &collection) {
-                                                auto mimeTypes = collection.contentMimeTypes().toSet();
+                                                auto mimeTypes = listToSet(collection.contentMimeTypes());
                                                 return !mimeTypes.intersects(allowedMimeTypes);
                                              }),
                               collections.end());
@@ -153,9 +148,9 @@ KJob *Storage::updateItem(Item item, QObject *parent)
     return new ItemModifyJob(item, parent);
 }
 
-KJob *Storage::removeItem(Item item)
+KJob *Storage::removeItem(Item item, QObject *parent)
 {
-    return new ItemDeleteJob(item);
+    return new ItemDeleteJob(item, parent);
 }
 
 KJob *Storage::removeItems(Item::List items, QObject *parent)
@@ -188,14 +183,14 @@ KJob *Storage::removeCollection(Collection collection, QObject *parent)
     return new CollectionDeleteJob(collection, parent);
 }
 
-KJob *Storage::createTransaction()
+KJob *Storage::createTransaction(QObject *parent)
 {
-    return new TransactionSequence();
+    return new TransactionSequence(parent);
 }
 
-CollectionFetchJobInterface *Storage::fetchCollections(Collection collection, StorageInterface::FetchDepth depth)
+CollectionFetchJobInterface *Storage::fetchCollections(Collection collection, StorageInterface::FetchDepth depth, QObject *parent)
 {
-    auto job = new CollectionJob(collection, jobTypeFromDepth(depth));
+    auto job = new CollectionJob(collection, jobTypeFromDepth(depth), parent);
 
     auto scope = job->fetchScope();
     scope.setContentMimeTypes({KCalCore::Todo::todoMimeType()});
@@ -207,18 +202,18 @@ CollectionFetchJobInterface *Storage::fetchCollections(Collection collection, St
     return job;
 }
 
-ItemFetchJobInterface *Storage::fetchItems(Collection collection)
+ItemFetchJobInterface *Storage::fetchItems(Collection collection, QObject *parent)
 {
-    auto job = new ItemJob(collection);
+    auto job = new ItemJob(collection, parent);
 
     configureItemFetchJob(job);
 
     return job;
 }
 
-ItemFetchJobInterface *Storage::fetchItem(Akonadi::Item item)
+ItemFetchJobInterface *Storage::fetchItem(Akonadi::Item item, QObject *parent)
 {
-    auto job = new ItemJob(item);
+    auto job = new ItemJob(item, parent);
 
     configureItemFetchJob(job);
 
