@@ -1,33 +1,15 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 David Faure <faure@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 David Faure <faure@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "zanshin021migrator.h"
 #include <akonadi/akonadicollectionfetchjobinterface.h>
 #include <akonadi/akonadiitemfetchjobinterface.h>
 #include <akonadi/akonadiserializer.h>
 
-#include <AkonadiCore/TransactionSequence>
-#include <AkonadiCore/ItemModifyJob>
+#include <AkonadiCore/Akonadi/TransactionSequence>
+#include <AkonadiCore/Akonadi/ItemModifyJob>
 
 #include <QStringList>
 #include <KCalCore/Todo>
@@ -50,12 +32,12 @@ Zanshin021Migrator::SeenItemHash Zanshin021Migrator::fetchAllItems()
 {
     SeenItemHash hash;
 
-    auto collectionsJob = m_storage.fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive);
+    auto collectionsJob = m_storage.fetchCollections(Akonadi::Collection::root(), Akonadi::Storage::Recursive, nullptr);
     collectionsJob->kjob()->exec();
 
     auto collections = collectionsJob->collections();
     foreach (const auto &collection, collections) {
-        auto job = m_storage.fetchItems(collection);
+        auto job = m_storage.fetchItems(collection, nullptr);
         job->kjob()->exec();
         auto items = job->items();
         foreach (const Akonadi::Item &item, items) {
