@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
-
-   Copyright 2014-2015 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+/*
+ * SPDX-FileCopyrightText: 2014-2015 Kevin Ottens <ervin@kde.org>
+ SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+
 #include "akonadistoragetestbase.h"
 
 #include <QTest>
@@ -34,9 +17,9 @@
 
 #include "utils/mem_fn.h"
 
-#include "AkonadiCore/qtest_akonadi.h"
+#include "AkonadiCore/akonadi/qtest_akonadi.h"
 
-#include <AkonadiCore/EntityDisplayAttribute>
+#include <AkonadiCore/Akonadi/EntityDisplayAttribute>
 
 #include "akonadi/akonadiapplicationselectedattribute.h"
 #include "akonadi/akonadicollectionfetchjobinterface.h"
@@ -100,7 +83,7 @@ void AkonadiStorageTestBase::shouldListCollections()
     auto storage = createStorage();
 
     // WHEN
-    auto job = storage->fetchCollections(collection, depth);
+    auto job = storage->fetchCollections(collection, depth, nullptr);
     AKVERIFYEXEC(job->kjob());
 
     // THEN
@@ -122,7 +105,8 @@ void AkonadiStorageTestBase::shouldRetrieveAllCollectionAncestors()
 
     // WHEN
     auto job = storage->fetchCollections(Akonadi::Collection::root(),
-                                         Akonadi::Storage::Recursive);
+                                         Akonadi::Storage::Recursive,
+                                         nullptr);
     AKVERIFYEXEC(job->kjob());
 
     // THEN
@@ -152,7 +136,7 @@ void AkonadiStorageTestBase::shouldListFullItemsInACollection()
                                           };
 
     // WHEN
-    auto job = storage->fetchItems(calendar2());
+    auto job = storage->fetchItems(calendar2(), nullptr);
     AKVERIFYEXEC(job->kjob());
 
     // THEN
@@ -200,7 +184,7 @@ void AkonadiStorageTestBase::shouldNotifyCollectionAdded()
 
     // WHEN
     auto storage = createStorage();
-    auto job = storage->createCollection(collection);
+    auto job = storage->createCollection(collection, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -232,7 +216,7 @@ void AkonadiStorageTestBase::shouldNotifyCollectionRemoved()
 
     // WHEN
     auto storage = createStorage();
-    auto job = storage->removeCollection(collection);
+    auto job = storage->removeCollection(collection, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -259,7 +243,7 @@ void AkonadiStorageTestBase::shouldNotifyCollectionChanged()
 
     // WHEN
     auto storage = createStorage();
-    auto job = storage->updateCollection(collection);
+    auto job = storage->updateCollection(collection, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -334,7 +318,7 @@ void AkonadiStorageTestBase::shouldNotifyItemRemoved()
 
     // WHEN
     auto storage = createStorage();
-    auto job = storage->removeItem(item);
+    auto job = storage->removeItem(item, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -377,7 +361,7 @@ void AkonadiStorageTestBase::shouldNotifyItemChanged()
 
     // WHEN
     auto storage = createStorage();
-    auto job = storage->updateItem(item);
+    auto job = storage->updateItem(item, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -433,7 +417,7 @@ void AkonadiStorageTestBase::shouldUpdateItem()
     item.setPayload<KCalCore::Todo::Ptr>(todo);
 
     // WHEN
-    auto job = storage->updateItem(item);
+    auto job = storage->updateItem(item, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -471,7 +455,7 @@ void AkonadiStorageTestBase::shouldUseTransaction()
     todo = item2.payload<KCalCore::Todo::Ptr>();
     todo->setSummary(QStringLiteral("Buy chocolate"));
 
-    auto transaction = storage->createTransaction();
+    auto transaction = storage->createTransaction(nullptr);
     storage->updateItem(item1, transaction);
     storage->updateItem(item3, transaction); // this job should fail
     storage->updateItem(item2, transaction);
@@ -480,12 +464,12 @@ void AkonadiStorageTestBase::shouldUseTransaction()
 
     // THEN
     QCOMPARE(spyUpdated.size(), 0);
-    auto job = storage->fetchItem(item1);
+    auto job = storage->fetchItem(item1, nullptr);
     AKVERIFYEXEC(job->kjob());
     QCOMPARE(job->items().size(), 1);
     item1 = job->items().at(0);
 
-    job = storage->fetchItem(item2);
+    job = storage->fetchItem(item2, nullptr);
     AKVERIFYEXEC(job->kjob());
     QCOMPARE(job->items().size(), 1);
     item2 = job->items().at(0);
@@ -540,7 +524,7 @@ void AkonadiStorageTestBase::shouldRetrieveItem()
     QVERIFY(findItem.isValid());
 
     // WHEN
-    auto job = storage->fetchItem(findItem);
+    auto job = storage->fetchItem(findItem, nullptr);
     AKVERIFYEXEC(job->kjob());
 
     // THEN
@@ -575,7 +559,7 @@ void AkonadiStorageTestBase::shouldMoveItem()
     QSignalSpy spyMoved(monitor.data(), &Akonadi::MonitorInterface::itemMoved);
     MonitorSpy monitorSpy(monitor.data());
 
-    auto job = storage->moveItem(item, calendar1());
+    auto job = storage->moveItem(item, calendar1(), nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spyMoved.isEmpty());
@@ -600,7 +584,7 @@ void AkonadiStorageTestBase::shouldMoveItems()
     QSignalSpy spyMoved(monitor.data(), &Akonadi::MonitorInterface::itemMoved);
     MonitorSpy monitorSpy(monitor.data());
 
-    auto job = storage->moveItems(list, calendar1());
+    auto job = storage->moveItems(list, calendar1(), nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spyMoved.isEmpty());
@@ -625,7 +609,7 @@ void AkonadiStorageTestBase::shouldDeleteItem()
     QVERIFY(item.isValid());
 
     //When
-    auto job = storage->removeItem(item);
+    auto job = storage->removeItem(item, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -656,7 +640,7 @@ void AkonadiStorageTestBase::shouldDeleteItems()
     list << item << item2;
 
     //When
-    auto job = storage->removeItems(list);
+    auto job = storage->removeItems(list, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!spy.isEmpty());
@@ -689,7 +673,7 @@ void AkonadiStorageTestBase::shouldUpdateCollection()
     auto attr = new Akonadi::EntityDisplayAttribute;
     attr->setDisplayName(QStringLiteral("Foo"));
     collection.addAttribute(attr);
-    auto job = storage->updateCollection(collection);
+    auto job = storage->updateCollection(collection, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!changeSpy.isEmpty());
@@ -720,7 +704,7 @@ void AkonadiStorageTestBase::shouldNotifyCollectionTimestampChanges()
 
     // WHEN
     collection.attribute<Akonadi::TimestampAttribute>(Akonadi::Collection::AddIfMissing)->refreshTimestamp();
-    auto job = storage->updateCollection(collection);
+    auto job = storage->updateCollection(collection, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!changeSpy.isEmpty());
@@ -753,7 +737,7 @@ void AkonadiStorageTestBase::shouldNotifyCollectionSelectionChanges()
     auto attr = new Akonadi::ApplicationSelectedAttribute;
     attr->setSelected(false);
     collection.addAttribute(attr);
-    auto job = storage->updateCollection(collection);
+    auto job = storage->updateCollection(collection, nullptr);
     AKVERIFYEXEC(job);
     monitorSpy.waitForStableState();
     QTRY_VERIFY(!changeSpy.isEmpty());
@@ -778,7 +762,7 @@ Akonadi::Item AkonadiStorageTestBase::fetchItemByRID(const QString &remoteId, co
     Akonadi::Item item;
     item.setRemoteId(remoteId);
 
-    auto job = createStorage()->fetchItem(item);
+    auto job = createStorage()->fetchItem(item, nullptr);
     job->setCollection(collection);
     if (!job->kjob()->exec()) {
         qWarning() << job->kjob()->errorString();
@@ -798,7 +782,7 @@ Akonadi::Collection AkonadiStorageTestBase::fetchCollectionByRID(const QString &
     Akonadi::Collection collection;
     collection.setRemoteId(remoteId);
 
-    auto job = createStorage()->fetchCollections(collection, Akonadi::StorageInterface::Base);
+    auto job = createStorage()->fetchCollections(collection, Akonadi::StorageInterface::Base, nullptr);
     job->setResource(QStringLiteral("akonadi_knut_resource_0"));
     if (!job->kjob()->exec()) {
         qWarning() << job->kjob()->errorString() << remoteId;
